==> nextcloud-app-richdocuments-1.1.25-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/en_GB.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Saving...",
    "Latest revision" : "Latest revision",
    "More versions..." : "More versions...",
    "Just now" : "Just now",
    "Failed to revert the document to older version" : "Failed to revert the document to older version",
    "Save" : "Save",
    "Loading documents..." : "Loading documents...",
    "Edit" : "Edit",
    "Document" : "Document",
    "Spreadsheet" : "Spreadsheet",
    "Presentation" : "Presentation",
    "Could not create file" : "Could not create file",
    "New Document.odt" : "New Document.odt",
    "New Spreadsheet.ods" : "New Spreadsheet.ods",
    "New Presentation.odp" : "New Presentation.odp",
    "Can't create document" : "Can't create document",
    "Saved" : "Saved",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Collabora Online server",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client.",
    "Apply" : "Apply",
    "Wrong password. Please retry." : "Incorrect password. Please try again.",
    "Password" : "Password",
    "OK" : "OK",
    "Guest %s" : "Guest %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "This link has expired or is incorrect. Please contact the person who shared it with you for details."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-richdocuments-1.12.31-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/en_GB.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Saving...",
    "Download this revision" : "Download this revision",
    "Restore this revision" : "Restore this revision",
    "Latest revision" : "Latest revision",
    "More versions..." : "More versions...",
    "Just now" : "Just now",
    "Failed to revert the document to older version" : "Failed to revert the document to older version",
    "Save" : "Save",
    "Loading documents..." : "Loading documents...",
    "Edit" : "Edit",
    "New Document" : "New Document",
    "New Spreadsheet" : "New Spreadsheet",
    "New Presentation" : "New Presentation",
    "Could not create file" : "Could not create file",
    "New Document.odt" : "New Document.odt",
    "New Spreadsheet.ods" : "New Spreadsheet.ods",
    "New Presentation.odp" : "New Presentation.odp",
    "New Document.docx" : "New Document.docx",
    "New Spreadsheet.xlsx" : "New Spreadsheet.xlsx",
    "New Presentation.pptx" : "New Presentation.pptx",
    "Can't create document" : "Can't create document",
    "Saved" : "Saved",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Saved with error: Collabora Online should use the same protocol as the server installation.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Collabora Online server",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client.",
    "Apply" : "Apply",
    "Use OOXML by default for new files" : "Use OOXML by default for new files",
    "Wrong password. Please retry." : "Incorrect password. Please try again.",
    "Password" : "Password",
    "OK" : "OK",
    "Guest %s" : "Guest %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "This link has expired or is incorrect. Please contact the person who shared it with you for details."
},
"nplurals=2; plural=(n != 1);");
